ProSHADE: Class Members - Functions

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

### - i -

- interpolateAlongFirst() : ProSHADE_internal_spheres::ProSHADE_sphere
- interpolateAlongSecond() : ProSHADE_internal_spheres::ProSHADE_sphere
- interpolateMapFromSpheres() : ProSHADE_internal_data::ProSHADE_data
- interpolateSphereValues() : ProSHADE_internal_spheres::ProSHADE_rotFun_sphere
- invertMirrorMap() : ProSHADE_internal_data::ProSHADE_data
- invertSHCoefficients() : ProSHADE_internal_data::ProSHADE_data